#[non_exhaustive]pub enum TypeError {
UnboundVariable(String),
TypeMismatch {
expected: ExprType,
got: ExprType,
},
CannotInfer,
}Expand description
Errors from type inference.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnboundVariable(String)
A variable was not found in the type environment.
TypeMismatch
An expression produced a type that does not match the expected type.
CannotInfer
The type of an expression could not be determined.